;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "easy-hugo" "20250908.2343"
  "Write blogs made with hugo by markdown or org-mode."
  '((emacs     "25.1")
    (request   "0.3.0")
    (transient "0.3.6"))
  :url "https://github.com/masasam/emacs-easy-hugo"
  :commit "ee4a6d2ee65d90c0c1739bc688d08f7b855a6b8a"
  :revdesc "ee4a6d2ee65d")
